ytree\.tree\_farm\.halo\_selector\.HaloSelector
===============================================

.. currentmodule:: ytree.tree_farm.halo_selector

.. autoclass:: HaloSelector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HaloSelector.__init__
   
   

   
   
   